@@ -143,7 +143,7 @@ class Payment(MuviBase):
             'site_id': self.site_id_cadena if self.marketplace else self.site_id,
             'site_transaction_id': site_transaction_id,
             'token': payment_data['token'],
-            'payment_method_id': 1,         # Peso Argentino
+            'payment_method_id': payment_data['payment_method_id'] if 'payment_method_id' in payment_data else 1,
             'bin': payment_data['bin'],     # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
             'payment_type': 'single',
