@@ -22,5 +22,5 @@ class Refund(MuviBase):
         }
         r = requests.post(self.url + f'/payments/{payment_id}/refunds', headers=self.headers, data=json.dumps(data))
         if r.status_code > 400:
-            return self.ok(r.json(), status=r.status_code)
-        return self.error(r.json(), status=r.status_code)
+            return self.ok(response=r.json(), status=r.status_code)
+        return self.error(response=r.json(), status=r.status_code)
