@@ -27,7 +27,7 @@ class Customer(MuviBase):
             if f not in client['domicilio']:
                 return self.error(message='domicilio.{} field is missing'.format(f))
 
-        return self.ok(client)
+        return self.ok(response=client)
 
     def create(self, client: dict) -> dict:
         """
@@ -43,7 +43,7 @@ class Customer(MuviBase):
 
         customer_response = self.sdk.customer().search(filters={'email': client['email']})
         if len(customer_response['response']['results']) > 0:
-            return self.ok(_format(customer_response['response']['results'][0]))
+            return self.ok(response=_format(customer_response['response']['results'][0]))
 
         try:
             street_number = int(client['domicilio']['altura'])
@@ -69,21 +69,21 @@ class Customer(MuviBase):
         }
         mp_response = self.sdk.customer().create(mp_customer_data)
         if mp_response['status'] < 400:
-            return self.ok(_format(mp_response['response']), status=mp_response['status'])
+            return self.ok(response=_format(mp_response['response']), status=mp_response['status'])
 
-        return self.error(mp_response['response'], status=mp_response['status'])
+        return self.error(response=mp_response['response'], status=mp_response['status'])
 
     def get(self, customer_id: str):
         mp_response = self.sdk.customer().get(customer_id)
         if mp_response['status'] < 400:
             customer = mp_response['response']
-            return self.ok(_format(customer), status=mp_response['status'])
+            return self.ok(response=_format(customer), status=mp_response['status'])
 
-        return self.error(mp_response['response'], status=mp_response['status'])
+        return self.error(response=mp_response['response'], status=mp_response['status'])
 
     def search(self, filters: dict):
         mp_response = self.sdk.customer().search(filters)
         if mp_response['status'] < 400:
-            return self.ok(mp_response['response'], status=mp_response['status'])
+            return self.ok(response=mp_response['response'], status=mp_response['status'])
 
-        return self.error(mp_response['response'], status=mp_response['status'])
+        return self.error(response=mp_response['response'], status=mp_response['status'])
